==> vue-dept-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/dept/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { IconPopup } from "@dftvue2-opentiny/vue-icon";
import Input from "@dftvue2-opentiny/vue-input";
import Row from "@dftvue2-opentiny/vue-row";
import Col from "@dftvue2-opentiny/vue-col";
import DialogBox from "@dftvue2-opentiny/vue-dialog-box";
import Select from "@dftvue2-opentiny/vue-select";
import Option from "@dftvue2-opentiny/vue-option";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyInput: Input,
    TinyDialogBox: DialogBox,
    TinySelect: Select,
    TinyOption: Option,
    TinyRow: Row,
    TinyCol: Col,
    IconPopup: IconPopup()
  },
  props: [].concat(props, ["size", "modelValue", "disabled", "fetchDeptList", "fetchDeptByValue", "fetchDept", "beforeConfirm", "autoSelect", "title", "displayOnly"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-dept"
  }, [_c("tiny-input", {
    attrs: {
      "size": _vm.size,
      "disabled": _vm.disabled,
      "readonly": "",
      "display-only": _vm.displayOnly
    },
    scopedSlots: _vm._u([{
      key: "suffix",
      fn: function fn() {
        return [_c("icon-popup", {
          staticClass: "tiny-input__icon tiny-svg-icon",
          on: {
            "click": _vm.openDialog
          }
        })];
      },
      proxy: true
    }]),
    model: {
      value: _vm.state.display,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "display", $$v);
      },
      expression: "state.display"
    }
  }), _c("tiny-dialog-box", {
    staticClass: "tiny-dept",
    attrs: {
      "visible": _vm.state.open,
      "close-on-click-modal": false,
      "width": "550px",
      "append-to-body": "",
      "title": _vm.title
    },
    on: {
      "update:visible": function updateVisible($event) {
        _vm.state.open = $event;
      },
      "close": _vm.closeDialog
    },
    scopedSlots: _vm._u([{
      key: "footer",
      fn: function fn() {
        return [_c("span", {
          staticClass: "tiny-toolbar"
        }, [_c("button", {
          staticClass: "tiny-button tiny-button--primary",
          attrs: {
            "type": "button"
          },
          on: {
            "click": _vm.confirm
          }
        }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.base.confirm")))])]), _c("button", {
          staticClass: "tiny-button tiny-button--default",
          attrs: {
            "type": "button"
          },
          on: {
            "click": _vm.cancel
          }
        }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.base.cancel")))])])])];
      },
      proxy: true
    }])
  }, [_c("tiny-row", {
    staticClass: "tiny-dept__search"
  }, [_c("tiny-col", {
    staticClass: "tiny-dept__label",
    attrs: {
      "title": _vm.t("ui.dept.search"),
      "span": 3
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.dept.search")) + " ")]), _c("tiny-col", {
    attrs: {
      "span": 5
    }
  }, [_c("tiny-select", {
    staticClass: "tiny-detp__select",
    attrs: {
      "placement": "bottom-start",
      "loading": _vm.state.loading,
      "placeholder": _vm.t("ui.dept.input"),
      "filterable": "",
      "clearable": "",
      "remote": "",
      "remote-method": _vm.searchMethod
    },
    on: {
      "change": _vm.searchChange
    },
    model: {
      value: _vm.state.searchValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "searchValue", $$v);
      },
      expression: "state.searchValue"
    }
  }, [_c("li", {
    staticClass: "tiny-option tiny-select-dropdown__item",
    staticStyle: {
      "background": "#f1f1f1",
      "cursor": "auto",
      "border-bottom": "solid 1px #d9d9d9",
      "box-shadow": "rgb(241, 241, 241) 0px -6px 0px 6px"
    }
  }, [_c("span", {
    staticStyle: {
      "float": "left",
      "font-size": "12px"
    }
  }, [_vm._v(_vm._s(_vm.t("ui.dept.code")))]), _c("span", {
    staticStyle: {
      "float": "right"
    }
  }, [_vm._v(_vm._s(_vm.t("ui.dept.name")))])]), _vm._l(_vm.state.searchOptions, function(option, index) {
    return _c("tiny-option", {
      key: index,
      attrs: {
        "label": option.hrName,
        "value": option.hrCode
      }
    }, [_c("span", {
      staticStyle: {
        "float": "left",
        "font-size": "12px"
      }
    }, [_vm._v(_vm._s(option.hrCode))]), _c("span", {
      staticStyle: {
        "float": "right",
        "color": "#8492a6",
        "font-size": "12px"
      }
    }, [_vm._v(_vm._s(option.hrName))])]);
  })], 2)], 1)], 1), _vm._l(_vm.deptState, function(dept, index) {
    return _c("tiny-row", {
      key: index,
      staticClass: "tiny-dept__item"
    }, [_c("tiny-col", {
      staticClass: "tiny-dept__label",
      attrs: {
        "title": _vm.t("ui.dept." + dept.title),
        "span": 3
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.dept." + dept.title)) + " ")]), _c("tiny-col", {
      attrs: {
        "span": 9
      }
    }, [_c("tiny-select", {
      ref: "select" + index,
      refInFor: true,
      staticClass: "tiny-detp__select",
      attrs: {
        "loading": _vm.state.loading,
        "filterable": "",
        "default-first-option": "",
        "clearable": "",
        "disabled": !!index && dept.disable
      },
      on: {
        "visible-change": function visibleChange($event) {
          return _vm.getCurrentList(index, $event);
        },
        "change": function change($event) {
          return _vm.selectChange({
            level: index,
            value: $event
          });
        }
      },
      model: {
        value: dept.value,
        callback: function callback($$v) {
          _vm.$set(dept, "value", $$v);
        },
        expression: "dept.value"
      }
    }, _vm._l(dept.options, function(option) {
      return _c("tiny-option", {
        key: option.hrCode,
        attrs: {
          "label": option.hrName,
          "value": option.hrCode
        }
      });
    }), 1)], 1)], 1);
  }), _c("tiny-row", [_c("p", {
    staticClass: "tiny-dept__label is-selected"
  }, [_vm._v(" " + _vm._s(_vm.t("ui.dept.selected")) + " ")]), _c("p", {
    staticClass: "tiny-dept__selected-info"
  }, [_vm._v(" " + _vm._s(_vm.state.labels.join(" > ")) + " ")]), _vm._t("hrapprover", null, {
    "slotScope": _vm.state
  })], 2)], 2)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-dept-2.23.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/dept/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { IconPopup } from '@opentinyvue/vue-icon';
import Input from '@opentinyvue/vue-input';
import Row from '@opentinyvue/vue-row';
import Col from '@opentinyvue/vue-col';
import DialogBox from '@opentinyvue/vue-dialog-box';
import Select from '@opentinyvue/vue-select';
import Option from '@opentinyvue/vue-option';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyInput: Input,
    TinyDialogBox: DialogBox,
    TinySelect: Select,
    TinyOption: Option,
    TinyRow: Row,
    TinyCol: Col,
    IconPopup: IconPopup()
  },
  emits: ["open", "selected", "cancel", "change", "update:modelValue", "confirm", "close"],
  props: [].concat(props, ["size", "modelValue", "disabled", "fetchDeptList", "fetchDeptByValue", "fetchDept", "beforeConfirm", "autoSelect", "title", "displayOnly"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-dept"
  }, [_c("tiny-input", {
    attrs: {
      "tiny_mode": "pc",
      "size": _vm.size,
      "disabled": _vm.disabled,
      "readonly": "",
      "display-only": _vm.displayOnly
    },
    scopedSlots: _vm._u([{
      key: "suffix",
      fn: function fn() {
        return [_c("icon-popup", {
          staticClass: "tiny-input__icon tiny-svg-icon",
          on: {
            "click": _vm.openDialog
          }
        })];
      },
      proxy: true
    }]),
    model: {
      value: _vm.state.display,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "display", $$v);
      },
      expression: "state.display"
    }
  }), _c("tiny-dialog-box", {
    staticClass: "tiny-dept",
    attrs: {
      "visible": _vm.state.open,
      "close-on-click-modal": false,
      "width": "550px",
      "append-to-body": "",
      "title": _vm.title
    },
    on: {
      "update:visible": function updateVisible($event) {
        _vm.state.open = $event;
      },
      "close": _vm.closeDialog
    },
    scopedSlots: _vm._u([{
      key: "footer",
      fn: function fn() {
        return [_c("span", {
          staticClass: "tiny-toolbar"
        }, [_c("button", {
          staticClass: "tiny-button tiny-button--primary",
          attrs: {
            "type": "button"
          },
          on: {
            "click": _vm.confirm
          }
        }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.base.confirm")))])]), _c("button", {
          staticClass: "tiny-button tiny-button--default",
          attrs: {
            "type": "button"
          },
          on: {
            "click": _vm.cancel
          }
        }, [_c("span", [_vm._v(_vm._s(_vm.t("ui.base.cancel")))])])])];
      },
      proxy: true
    }])
  }, [_c("tiny-row", {
    staticClass: "tiny-dept__search"
  }, [_c("tiny-col", {
    staticClass: "tiny-dept__label",
    attrs: {
      "title": _vm.t("ui.dept.search"),
      "span": 3
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.dept.search")) + " ")]), _c("tiny-col", {
    attrs: {
      "span": 5
    }
  }, [_c("tiny-select", {
    staticClass: "tiny-detp__select",
    attrs: {
      "placement": "bottom-start",
      "loading": _vm.state.loading,
      "placeholder": _vm.t("ui.dept.input"),
      "filterable": "",
      "clearable": "",
      "remote": "",
      "remote-method": _vm.searchMethod
    },
    on: {
      "change": _vm.searchChange,
      "clear": function clear($event) {
        return _vm.searchMethod("");
      }
    },
    model: {
      value: _vm.state.searchValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "searchValue", $$v);
      },
      expression: "state.searchValue"
    }
  }, [_c("li", {
    staticClass: "tiny-option tiny-select-dropdown__item",
    staticStyle: {
      "background": "#f1f1f1",
      "cursor": "auto",
      "border-bottom": "solid 1px #d9d9d9",
      "box-shadow": "rgb(241, 241, 241) 0px -6px 0px 6px"
    }
  }, [_c("span", {
    staticStyle: {
      "float": "left",
      "font-size": "12px"
    }
  }, [_vm._v(_vm._s(_vm.t("ui.dept.code")))]), _c("span", {
    staticStyle: {
      "float": "right"
    }
  }, [_vm._v(_vm._s(_vm.t("ui.dept.name")))])]), _vm._l(_vm.state.searchOptions, function(option, index) {
    return _c("tiny-option", {
      key: index,
      attrs: {
        "label": option.hrName,
        "value": option.hrCode
      }
    }, [_c("span", {
      staticStyle: {
        "float": "left",
        "font-size": "12px"
      }
    }, [_vm._v(_vm._s(option.hrCode))]), _c("span", {
      staticStyle: {
        "float": "right",
        "color": "#8492a6",
        "font-size": "12px"
      }
    }, [_vm._v(_vm._s(option.hrName))])]);
  })], 2)], 1)], 1), _vm._l(_vm.deptState, function(dept, index) {
    return _c("tiny-row", {
      key: index,
      staticClass: "tiny-dept__item"
    }, [_c("tiny-col", {
      staticClass: "tiny-dept__label",
      attrs: {
        "title": _vm.t("ui.dept." + dept.title),
        "span": 3
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.dept." + dept.title)) + " ")]), _c("tiny-col", {
      attrs: {
        "span": 9
      }
    }, [_c("tiny-select", {
      ref: "select" + index,
      refInFor: true,
      staticClass: "tiny-detp__select",
      attrs: {
        "loading": _vm.state.loading,
        "filterable": "",
        "default-first-option": "",
        "clearable": "",
        "disabled": !!index && dept.disable
      },
      on: {
        "visible-change": function visibleChange($event) {
          return _vm.getCurrentList(index, $event);
        },
        "change": function change($event) {
          return _vm.selectChange({
            level: index,
            value: $event
          });
        }
      },
      model: {
        value: dept.value,
        callback: function callback($$v) {
          _vm.$set(dept, "value", $$v);
        },
        expression: "dept.value"
      }
    }, _vm._l(dept.options, function(option) {
      return _c("tiny-option", {
        key: option.hrCode,
        attrs: {
          "label": option.hrName,
          "value": option.hrCode
        }
      });
    }), 1)], 1)], 1);
  }), _c("tiny-row", [_c("p", {
    staticClass: "tiny-dept__label is-selected"
  }, [_vm._v(" " + _vm._s(_vm.t("ui.dept.selected")) + " ")]), _c("p", {
    staticClass: "tiny-dept__selected-info"
  }, [_vm._v(" " + _vm._s(_vm.state.labels.join(" > ")) + " ")]), _vm._t("hrapprover", null, {
    "slotScope": _vm.state
  })], 2)], 2)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
